@@ -10,11 +10,10 @@ class Filter
     Class obj;
     public:
         template <typename Arg>
-        typename std::result_of<Class(Arg)>::type
-            operator()(Arg const &arg) const
-            {
-                return obj(arg);
-            }
+        std::invoke_result<Class, Arg>::type operator()(Arg const &arg) const
+        {
+            return obj(arg);
+        }
 };
 
 
