@@ -1,9 +1,9 @@
-#ifndef _INCLUDED_OFDNSTREAMBUF_H_
-#define _INCLUDED_OFDNSTREAMBUF_H_
+#ifndef INCLUDED_OFDNSTREAMBUF_H_
+#define INCLUDED_OFDNSTREAMBUF_H_
 
-#ifndef _INCLUDED_STREAMBUF_
+#ifndef INCLUDED_STREAMBUF_
 #include <streambuf>
-#define _INCLUDED_STREAMBUF_
+#define INCLUDED_STREAMBUF_
 #endif
 
 namespace FBB
