@@ -7,12 +7,12 @@
     {
         list<string> object;
 
-        object.push_back(string("Hello"));
-        object.push_back(string("World"));
-        object.push_back(string("Hello"));
-        object.push_back(string("World"));
+        object.push_back("Hello"s);
+        object.push_back("World"s);
+        object.push_back("Hello"s);
+        object.push_back("World"s);
 
-        object.remove(string("Hello"));
+        object.remove("Hello"s);
 
         while (object.size())
         {
