@@ -17,8 +17,8 @@ class Digit: public Awaiter
     std::coroutine_handle<State> d_handle;
 
     public:
-        typedef State promise_type;
-        typedef std::coroutine_handle<State> Handle;
+        using promise_type = State;
+        using Handle = std::coroutine_handle<State>;
 
         explicit Digit(Handle handle);
         ~Digit();
