@@ -7,7 +7,7 @@ class Recursive
 {
     class State: public PromiseBase<Recursive, State>
     {
-        typedef std::coroutine_handle<State> Handle;
+        using Handle = std::coroutine_handle<State>;
 
         size_t d_value;
 
@@ -17,11 +17,11 @@ class Recursive
     };
 
     private:
-        typedef std::coroutine_handle<State> Handle;
+        using Handle = std::coroutine_handle<State>;
         Handle d_handle;
 
     public:
-        typedef State promise_type;
+        using promise_type = State;
 
         explicit Recursive(std::coroutine_handle<State> handle);
         ~Recursive();
