@@ -8,6 +8,20 @@
             ~Inner();
             void fun();
     };
+    Inner::Inner()
+    {
+        cout << "Inner constructor\n";
+    }
+    Inner::~Inner()
+    {
+        cout << "Inner destructor\n";
+    }
+    void Inner::fun()
+    {
+        cout << "Inner fun\n";
+        throw 1;
+        cout << "This statement is not executed\n";
+    }
 
     class Outer
     {
@@ -17,51 +31,29 @@
             void fun();
     };
 
-    Inner::Inner()
-    {
-        cout << "Inner constructor\n";
-    }
-
-    Inner::~Inner()
-    {
-        cout << "Inner destructor\n";
-    }
-
-    void Inner::fun()
-    {
-        cout << "Inner fun\n";
-        throw 1;
-        cout << "This statement is not executed\n";
-    }
-
     Outer::Outer()
     {
         cout << "Outer constructor\n";
     }
-
     Outer::~Outer()
     {
         cout << "Outer destructor\n";
     }
-
     void Outer::fun()
     {
         Inner in;
-
         cout << "Outer fun\n";
         in.fun();
     }
 
-
     int main()
     {
         Outer out;
-
         try
         {
             out.fun();
         }
-        catch (...)
+        catch (int x)
         {}
     }
     /*
